from pydantic import BaseModel
from typing import Optional
from datetime import datetime
from controlresell_connector.com.controlresell.connector.models.jobs.conversations.inbox.JobConversationInboxOppositeUser import JobConversationInboxOppositeUser

class JobConversationInbox(BaseModel):
    id: str
    isDeletionRestricted: Optional[bool] = None
    unread: Optional[bool] = None
    updatedAt: datetime
    oppositeUser: Optional[JobConversationInboxOppositeUser] = None



from pydantic import BaseModel
from controlresell_connector.com.controlresell.connector.models.jobs.posts.JobPostListed import JobPostListed
from typing import Optional

class JobPostsListResponse(BaseModel):
    posts: list[JobPostListed]
    nextOffset: Optional[int] = None



from pydantic import BaseModel
from uuid import UUID
from controlresell_connector.com.controlresell.connector.models.jobs.posts.create.JobPostsCreatePayload import JobPostsCreatePayload

class JobPostsCreatePayloadWithAccounts(BaseModel):
    accountsId: list[UUID]
    payload: JobPostsCreatePayload



from pydantic import BaseModel
from typing import Optional
from controlresell_connector.com.controlresell.connector.models.jobs.auth.data.UserAddress import UserAddress

class JobAuthDataResponse(BaseModel):
    id: Optional[str] = None
    name: Optional[str] = None
    userAddress: Optional[UserAddress] = None



from pydantic import BaseModel
from uuid import UUID
from controlresell_connector.com.controlresell.connector.models.jobs.conversations.offers.JobConversationOffer import JobConversationOffer

class JobConversationsOffersCreateResponse(BaseModel):
    offerId: UUID
    offer: JobConversationOffer



from pydantic import BaseModel
from typing import Optional
from controlresell_connector.com.controlresell.connector.models.jobs.orders.JobOrderStatus import JobOrderStatus
from datetime import datetime

class JobOrder(BaseModel):
    id: str
    conversationId: Optional[str] = None
    transactionId: Optional[str] = None
    price: float
    currencyCode: str
    status: JobOrderStatus
    date: datetime
    transactionUserStatus: Optional[str] = None



from pydantic import BaseModel
from uuid import UUID
from typing import Optional
from controlresell_connector.com.controlresell.connector.models.jobs.conversations.JobConversationUserRole import JobConversationUserRole

class JobConversationsOffersCreatePayload(BaseModel):
    accountId: UUID
    offerId: UUID
    transactionId: Optional[str] = None
    conversationId: str
    role: JobConversationUserRole
    price: float
    currency: str



from pydantic import BaseModel
from uuid import UUID
from controlresell_connector.com.controlresell.connector.models.jobs.posts.JobPostOptionals import JobPostOptionals

class JobPostsUpdatePayload(BaseModel):
    accountId: UUID
    platformId: str
    post: JobPostOptionals



from pydantic import BaseModel
from typing import Optional

class JobPostOptionals(BaseModel):
    brand: Optional[str] = None
    catalogId: Optional[int] = None
    colorIds: Optional[list[int]] = None
    description: Optional[str] = None
    measurementLength: Optional[float] = None
    measurementWidth: Optional[float] = None
    packageSizeId: Optional[int] = None
    photoUrls: Optional[list[str]] = None
    price: Optional[float] = None
    sizeId: Optional[int] = None
    statusId: Optional[int] = None
    title: Optional[str] = None
    isDraft: Optional[bool] = None
    material: Optional[list[int]] = None
    manufacturerLabelling: Optional[str] = None



from pydantic import BaseModel
from datetime import datetime
from typing import Optional

class JobConversationOppositeUser(BaseModel):
    id: str
    login: str
    lastLoggedInAt: Optional[datetime] = None
    isSystem: Optional[bool] = None
    reviewCount: Optional[int] = None
    reviewValue: Optional[float] = None
    isOnHoliday: Optional[bool] = None
    isModerator: Optional[bool] = None
    photo: Optional[str] = None
    location: Optional[str] = None



from pydantic import BaseModel
from uuid import UUID
from controlresell_connector.com.controlresell.connector.models.accounts.AccountPlatform import AccountPlatform
from typing import Optional

class AccountLabels(BaseModel):
    id: UUID
    platform: AccountPlatform
    name: Optional[str] = None
    username: Optional[str] = None



from pydantic import BaseModel
from typing import Optional

class UserAddress(BaseModel):
    id: str
    userId: str
    countryId: int
    entryType: int
    name: str
    postalCode: str
    city: str
    state: str
    line1: str
    line2: Optional[str] = None
    createdAt: str
    isComplete: bool
    countryCode: str
    countryIsoCode: str
    country: str



from enum import Enum

class JobOrderStatus(str, Enum):
    PAYMENT_VALIDATED = 'PAYMENT_VALIDATED'
    SHIPPING_LABEL_SENT_TO_SELLER = 'SHIPPING_LABEL_SENT_TO_SELLER'
    ORDER_SHIPPED = 'ORDER_SHIPPED'
    DELIVERED_TO_POST_OFFICE_OR_PICKUP_POINT = 'DELIVERED_TO_POST_OFFICE_OR_PICKUP_POINT'
    ORDER_RECEIVED = 'ORDER_RECEIVED'
    ORDER_FINALIZED = 'ORDER_FINALIZED'
    RETURN_INITIATED = 'RETURN_INITIATED'
    REFUND_DONE = 'REFUND_DONE'
    UNKNOWN = 'UNKNOWN'



from pydantic import BaseModel
from typing import Optional
from controlresell_connector.com.controlresell.connector.models.jobs.conversations.JobConversationOppositeUser import JobConversationOppositeUser
from controlresell_connector.com.controlresell.connector.models.jobs.conversations.JobConversationTransaction import JobConversationTransaction
from controlresell_connector.com.controlresell.connector.models.jobs.conversations.messages.JobConversationMessage import JobConversationMessage

class JobConversation(BaseModel):
    id: str
    readByCurrentUser: Optional[bool] = None
    readByOppositeUser: Optional[bool] = None
    allowReply: Optional[bool] = None
    isSuspicious: Optional[bool] = None
    isDeletionRestricted: Optional[bool] = None
    userHasSupportRole: Optional[bool] = None
    oppositeUser: Optional[JobConversationOppositeUser] = None
    transaction: Optional[JobConversationTransaction] = None
    messages: list[JobConversationMessage]



from pydantic import BaseModel
from uuid import UUID
from typing import Optional

class JobOrdersListPayload(BaseModel):
    accountId: UUID
    recent: Optional[bool] = None
    offset: Optional[int] = None



from pydantic import BaseModel
from typing import Optional
from datetime import datetime
from controlresell_connector.com.controlresell.connector.models.jobs.posts.JobPostOptionals import JobPostOptionals

class JobPostListed(BaseModel):
    platformId: str
    platformUrl: Optional[str] = None
    sold: Optional[bool] = None
    createdAt: Optional[datetime] = None
    post: JobPostOptionals
    data: Optional[str] = None



from pydantic import BaseModel
from typing import Optional
from datetime import datetime

class UpdateAccountPayload(BaseModel):
    credentials: Optional[str] = None
    data: Optional[str] = None
    lastTask: Optional[datetime] = None



from pydantic import BaseModel
from zodable_idschema import IdSchema
from uuid import UUID
from controlresell_connector.com.controlresell.connector.models.accounts.AccountPlatform import AccountPlatform
from typing import Optional
from datetime import datetime

class Account(BaseModel):
    id: UUID
    platform: AccountPlatform
    ownerId: IdSchema
    credentials: Optional[str] = None
    data: Optional[str] = None
    lastTask: Optional[datetime] = None



from pydantic import BaseModel
from controlresell_connector.com.controlresell.connector.models.jobs.conversations.inbox.JobConversationInbox import JobConversationInbox

class JobConversationsInboxGetResponse(BaseModel):
    conversations: list[JobConversationInbox]



from pydantic import BaseModel
from uuid import UUID
from typing import Optional

class JobOrdersLabelsGetPayload(BaseModel):
    accountId: UUID
    orderId: str
    transactionId: Optional[str] = None
    conversationId: Optional[str] = None
    shipmentId: Optional[str] = None



from pydantic import BaseModel
from typing import Optional

class JobPost(BaseModel):
    brand: str
    catalogId: int
    colorIds: Optional[list[int]] = None
    description: str
    measurementLength: Optional[float] = None
    measurementWidth: Optional[float] = None
    packageSizeId: int
    photoUrls: list[str]
    price: float
    sizeId: Optional[int] = None
    statusId: int
    title: str
    isDraft: bool
    material: Optional[list[int]] = None
    manufacturerLabelling: Optional[str] = None



from pydantic import BaseModel
from controlresell_connector.com.controlresell.connector.models.jobs.posts.JobPostOptionals import JobPostOptionals

class JobPostsUpdateResponse(BaseModel):
    platformId: str
    post: JobPostOptionals



from pydantic import BaseModel
from zodable_idschema import IdSchema
from uuid import UUID
from controlresell_connector.com.controlresell.connector.models.jobs.posts.JobPost import JobPost

class JobPostsCompletionPayload(BaseModel):
    accountId: UUID
    itemId: IdSchema
    platformId: str
    post: JobPost



from pydantic import BaseModel
from typing import Generic
from typing import TypeVar
from uuid import UUID
from typing import Optional

Response = TypeVar('Response')
Error = TypeVar('Error')
class JobResponseWebhook(BaseModel, Generic[Response, Error]):
    accountId: UUID
    response: Optional[Response] = None
    error: Optional[Error] = None



from pydantic import BaseModel
from typing import Generic
from typing import TypeVar
from controlresell_connector.com.controlresell.connector.models.accounts.Account import Account

T = TypeVar('T')
class JobRequest(BaseModel, Generic[T]):
    account: Account
    payload: T



from pydantic import BaseModel
from zodable_idschema import IdSchema
from controlresell_connector.com.controlresell.connector.models.accounts.AccountPlatform import AccountPlatform

class CreateAccountPayload(BaseModel):
    platform: AccountPlatform
    ownerId: IdSchema
    credentials: str
